@@ -170,6 +170,10 @@ impl ScopeVisitor {
     }
 
     fn read_expression(&mut self, expression: &ast::Expression) {
+        #[cfg_attr(
+            feature = "force_exhaustive_checks",
+            deny(non_exhaustive_omitted_patterns)
+        )]
         match expression {
             ast::Expression::Parentheses { expression, .. }
             | ast::Expression::UnaryOperator { expression, .. } => {
@@ -211,6 +215,23 @@ impl ScopeVisitor {
 
                 ast::Value::Var(var) => self.read_var(var),
 
+                #[cfg(feature = "roblox")]
+                ast::Value::IfExpression(if_expression) => {
+                    self.read_expression(if_expression.condition());
+                    self.read_expression(if_expression.if_expression());
+
+                    if let Some(else_if_expressions) = if_expression.else_if_expressions() {
+                        for else_if_expression in else_if_expressions {
+                            self.read_expression(else_if_expression.condition());
+                            self.read_expression(else_if_expression.expression());
+                        }
+                    }
+
+                    self.read_expression(if_expression.else_expression());
+                }
+
+                ast::Value::Number(_) | ast::Value::String(_) => {}
+
                 _ => {}
             },
 
@@ -219,6 +240,10 @@ impl ScopeVisitor {
     }
 
     fn read_prefix(&mut self, prefix: &ast::Prefix) {
+        #[cfg_attr(
+            feature = "force_exhaustive_checks",
+            deny(non_exhaustive_omitted_patterns)
+        )]
         match prefix {
             ast::Prefix::Expression(expression) => self.read_expression(expression),
             ast::Prefix::Name(name) => self.read_name(name),
@@ -227,6 +252,10 @@ impl ScopeVisitor {
     }
 
     fn read_suffix(&mut self, suffix: &ast::Suffix) {
+        #[cfg_attr(
+            feature = "force_exhaustive_checks",
+            deny(non_exhaustive_omitted_patterns)
+        )]
         match suffix {
             ast::Suffix::Call(call) => self.visit_call(call),
             ast::Suffix::Index(index) => self.visit_index(index),
@@ -258,6 +287,10 @@ impl ScopeVisitor {
 
     fn read_table_constructor(&mut self, table: &ast::TableConstructor) {
         for field in table.fields() {
+            #[cfg_attr(
+                feature = "force_exhaustive_checks",
+                deny(non_exhaustive_omitted_patterns)
+            )]
             match field {
                 ast::Field::ExpressionKey { key, value, .. } => {
                     self.read_expression(key);
@@ -278,6 +311,10 @@ impl ScopeVisitor {
     }
 
     fn read_var(&mut self, var: &ast::Var) {
+        #[cfg_attr(
+            feature = "force_exhaustive_checks",
+            deny(non_exhaustive_omitted_patterns)
+        )]
         match var {
             ast::Var::Expression(var_expr) => {
                 self.read_prefix(var_expr.prefix());
@@ -396,7 +433,7 @@ impl ScopeVisitor {
     }
 
     fn open_scope<N: Node>(&mut self, node: N) {
-        let scope = create_scope(node).unwrap_or_else(Default::default);
+        let scope = create_scope(node).unwrap_or_default();
         let scope_id = self.scope_manager.scopes.alloc(scope);
         self.scope_stack.push(scope_id);
     }
@@ -420,6 +457,10 @@ impl Visitor for ScopeVisitor {
                 self.read_expression(expression);
             }
 
+            #[cfg_attr(
+                feature = "force_exhaustive_checks",
+                deny(non_exhaustive_omitted_patterns)
+            )]
             let name = match var {
                 ast::Var::Expression(var_expr) => match var_expr.prefix() {
                     ast::Prefix::Expression(expression) => {
@@ -494,12 +535,20 @@ impl Visitor for ScopeVisitor {
     }
 
     fn visit_call(&mut self, call: &ast::Call) {
+        #[cfg_attr(
+            feature = "force_exhaustive_checks",
+            deny(non_exhaustive_omitted_patterns)
+        )]
         let arguments = match call {
             ast::Call::AnonymousCall(args) => args,
             ast::Call::MethodCall(method_call) => method_call.args(),
             _ => return,
         };
 
+        #[cfg_attr(
+            feature = "force_exhaustive_checks",
+            deny(non_exhaustive_omitted_patterns)
+        )]
         match arguments {
             ast::FunctionArgs::Parentheses { arguments, .. } => {
                 for argument in arguments {
@@ -511,6 +560,8 @@ impl Visitor for ScopeVisitor {
                 self.read_table_constructor(table_constructor);
             }
 
+            ast::FunctionArgs::String(_) => {}
+
             _ => {}
         }
     }
@@ -711,4 +762,11 @@ impl Visitor for ScopeVisitor {
     fn visit_while_end(&mut self, _: &ast::While) {
         self.close_scope();
     }
+
+    #[cfg(feature = "roblox")]
+    fn visit_type_info(&mut self, type_info: &ast::types::TypeInfo) {
+        if let ast::types::TypeInfo::Module { module, .. } = type_info {
+            self.read_name(module);
+        }
+    }
 }
