@@ -22,7 +22,7 @@ impl Rule for ParentheseConditionsLint {
             positions: Vec::new(),
         };
 
-        visitor.visit_ast(&ast);
+        visitor.visit_ast(ast);
 
         visitor
             .positions
