@@ -101,6 +101,10 @@ fn name_path(expression: &ast::Expression) -> Option<Vec<String>> {
 // Otherwise, returns None
 // Only attempts to resolve constants
 fn get_argument_type(expression: &ast::Expression) -> Option<PassedArgumentType> {
+    #[cfg_attr(
+        feature = "force_exhaustive_checks",
+        deny(non_exhaustive_omitted_patterns)
+    )]
     match expression {
         ast::Expression::Parentheses { expression, .. } => get_argument_type(expression),
 
@@ -123,6 +127,10 @@ fn get_argument_type(expression: &ast::Expression) -> Option<PassedArgumentType>
             ast::Value::String(token) => {
                 Some(PassedArgumentType::from_string(token.token().to_string()))
             }
+            #[cfg_attr(
+                feature = "force_exhaustive_checks",
+                allow(non_exhaustive_omitted_patterns)
+            )]
             ast::Value::Symbol(symbol) => match *symbol.token_type() {
                 TokenType::Symbol { symbol } => match symbol {
                     Symbol::False => Some(ArgumentType::Bool.into()),
@@ -141,6 +149,29 @@ fn get_argument_type(expression: &ast::Expression) -> Option<PassedArgumentType>
             },
             ast::Value::TableConstructor(_) => Some(ArgumentType::Table.into()),
             ast::Value::Var(_) => None,
+
+            #[cfg(feature = "roblox")]
+            ast::Value::IfExpression(if_expression) => {
+                // This could be a union type
+                let expected_type = get_argument_type(if_expression.if_expression())?;
+
+                if let Some(else_if_expressions) = if_expression.else_if_expressions() {
+                    for else_if_expression in else_if_expressions {
+                        if !get_argument_type(else_if_expression.expression())?
+                            .same_type(&expected_type)
+                        {
+                            return None;
+                        }
+                    }
+                }
+
+                if get_argument_type(if_expression.else_expression())?.same_type(&expected_type) {
+                    Some(expected_type)
+                } else {
+                    None
+                }
+            }
+
             _ => None,
         },
 
@@ -152,6 +183,10 @@ fn get_argument_type(expression: &ast::Expression) -> Option<PassedArgumentType>
             match binop {
                 ast::BinOp::Caret(_) => Some(ArgumentType::Number.into()),
 
+                #[cfg_attr(
+                    feature = "force_exhaustive_checks",
+                    allow(non_exhaustive_omitted_patterns)
+                )]
                 ast::BinOp::GreaterThan(_)
                 | ast::BinOp::GreaterThanEqual(_)
                 | ast::BinOp::LessThan(_)
@@ -485,6 +520,10 @@ impl Visitor for StandardLibraryVisitor<'_> {
 
         let mut argument_types = Vec::new();
 
+        #[cfg_attr(
+            feature = "force_exhaustive_checks",
+            deny(non_exhaustive_omitted_patterns)
+        )]
         match function_args {
             ast::FunctionArgs::Parentheses { arguments, .. } => {
                 for argument in arguments {
@@ -524,6 +563,7 @@ impl Visitor for StandardLibraryVisitor<'_> {
                     ast::Value::FunctionCall(_) => {
                         maybe_more_arguments = true;
                     }
+
                     ast::Value::Symbol(token_ref) => {
                         if let TokenType::Symbol { symbol } = token_ref.token().token_type() {
                             if symbol == &full_moon::tokenizer::Symbol::Ellipse {
@@ -531,6 +571,7 @@ impl Visitor for StandardLibraryVisitor<'_> {
                             }
                         }
                     }
+
                     _ => {}
                 }
             }
@@ -648,6 +689,14 @@ impl PassedArgumentType {
         }
     }
 
+    fn same_type(&self, other: &PassedArgumentType) -> bool {
+        match (self, other) {
+            (PassedArgumentType::Primitive(a), PassedArgumentType::Primitive(b)) => a == b,
+            (PassedArgumentType::String(_), PassedArgumentType::String(_)) => true,
+            _ => false,
+        }
+    }
+
     fn type_name(&self) -> String {
         match self {
             PassedArgumentType::Primitive(argument_type) => argument_type.to_string(),
@@ -861,4 +910,14 @@ mod tests {
             "writing",
         );
     }
+
+    #[cfg(feature = "roblox")]
+    #[test]
+    fn test_if_expressions() {
+        test_lint(
+            StandardLibraryLint::new(()).unwrap(),
+            "standard_library",
+            "if_expressions",
+        );
+    }
 }
