@@ -2,3 +2,5 @@ Color3.new(255, 0, 0)
 Color3.fromRGB(255, 0, 0)
 Color3.new(1, 0, 0)
 Color3.new(255 / 255, 0, 0)
+Color3.new(-1, 0, 0)
+Color3.new(a, b, c)
